==> printing-authority-1.2-sources.jar: ch/openchvote/printingauthority/plain/states/E1.java <==
/*
 * Copyright (C) 2022 Berner Fachhochschule https://e-voting.bfh.ch
 *
 *  - This program is free software: you can redistribute it and/or modify                           -
 *  - it under the terms of the GNU Affero General Public License as published by                    -
 *  - the Free Software Foundation, either version 3 of the License, or                              -
 *  - (at your option) any later version.                                                            -
 *  -                                                                                                -
 *  - This program is distributed in the hope that it will be useful,                                -
 *  - but WITHOUT ANY WARRANTY; without even the implied warranty of                                 -
 *  - MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                                   -
 *  - GNU General Public License for more details.                                                   -
 *  -                                                                                                -
 *  - You should have received a copy of the GNU Affero General Public License                       -
 *  - along with this program. If not, see <http://www.gnu.org/licenses/>.                           -
 */
package ch.openchvote.printingauthority.plain.states;

import ch.openchvote.framework.State;
import ch.openchvote.printingauthority.PrintingAuthority;
import ch.openchvote.printingauthority.plain.EventData;

public class E1 extends State<PrintingAuthority, EventData> {

    public E1() {
        super(Type.ERROR);
    }

}

==> printing-authority-1.2.1-sources.jar: ch/openchvote/printingauthority/plain/states/E1.java <==
/*
 * Copyright (C) 2022 Berner Fachhochschule https://e-voting.bfh.ch
 *
 *  - This program is free software: you can redistribute it and/or modify                           -
 *  - it under the terms of the GNU Affero General Public License as published by                    -
 *  - the Free Software Foundation, either version 3 of the License, or                              -
 *  - (at your option) any later version.                                                            -
 *  -                                                                                                -
 *  - This program is distributed in the hope that it will be useful,                                -
 *  - but WITHOUT ANY WARRANTY; without even the implied warranty of                                 -
 *  - MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                                   -
 *  - GNU General Public License for more details.                                                   -
 *  -                                                                                                -
 *  - You should have received a copy of the GNU Affero General Public License                       -
 *  - along with this program. If not, see <http://www.gnu.org/licenses/>.                           -
 */
package ch.openchvote.printingauthority.plain.states;

import ch.openchvote.framework.State;
import ch.openchvote.printingauthority.PrintingAuthority;
import ch.openchvote.printingauthority.plain.EventData;

public final class E1 extends State<PrintingAuthority, EventData> {

    public E1() {
        super(Type.ERROR);
    }

}
